@@ -12,14 +12,14 @@
     ## --------------------------------------------------------------------
     if (!is(x, "TDR")) stop ("x is not a TDR object")
     ## Detect trips
-    detp <- detPhase(tdrTime(x), depth(x), landerr=landerr,
-                     seaerr=seaerr, dtime(x))
+    detp <- detPhase(getTime(x), getDepth(x), landerr=landerr,
+                     seaerr=seaerr, getDtime(x))
     zd <- if (missing(offset)) {
-        zoc(tdrTime(x), depth(x))
-    } else zoc(tdrTime(x), depth(x), offset=offset)
+        zoc(getTime(x), getDepth(x))
+    } else zoc(getTime(x), getDepth(x), offset=offset)
     if (!is.null(zd)) x@depth <- zd
-    detd <- detDive(tdrTime(x), depth(x), detp[[2]],
-                    divethres, dtime(x))
+    detd <- detDive(getTime(x), getDepth(x), detp[[2]],
+                    divethres, getDtime(x))
 
     ## label phases of dives with their activity
     phaselabs <- labDivePhase(x, detd[, 1])
@@ -37,7 +37,7 @@
 
 "calibrateVel" <- function(x, type="all", calType="pooled",
                            bad=c(0, 0), z=0,
-                           filename=slot(tdr(x), "file"), coefs, ...)
+                           filename=slot(getTDR(x), "file"), coefs, ...)
 {
     ## Purpose: Calibrate velocity
     ## --------------------------------------------------------------------
@@ -50,22 +50,22 @@
     if (!is(slot(x, "tdr"), "TDRvel")) {
         stop ("tdr slot in x does not contain a TDRvel object")
     }
-    tt <- tdr(x)
+    tt <- getTDR(x)
     if (!missing(coefs)) {
-        vel <- (velocity(tt) - coefs[1]) / coefs[2]
+        vel <- (getVeloc(tt) - coefs[1]) / coefs[2]
         x@tdr@velocity <- vel
         x@vel.calib.coefs <- coefs
         x
     } else {
-        ddepthvel <- .getVelCalib(time=tdrTime(tt),
-                                  zdepth=depth(tt),
-                                  vel=velocity(tt),
-                                  dives=diveAct(x),
-                                  phase=dPhaseLab(x),
+        ddepthvel <- .getVelCalib(time=getTime(tt),
+                                  zdepth=getDepth(tt),
+                                  vel=getVeloc(tt),
+                                  dives=getDAct(x),
+                                  phase=getDPhaseLab(x),
                                   type=type, z=z,
-                                  interval=dtime(tt))
+                                  interval=getDtime(tt))
 
-        calibrate <- doVelCalib(ddepthvel, vel=velocity(tt),
+        calibrate <- doVelCalib(ddepthvel, vel=getVeloc(tt),
                                 calType=calType, bad=bad,
                                 filename=filename, ...)
 
