@@ -9,10 +9,9 @@
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
     require(tcltk) || stop("tcltk support is absent")
-    require(chron) || stop("chron is required to handle time")
-    rx <- range(as.numeric(time))     # max and min of dates
-    xlim <- x10 <- if(is.null(xlim)) {    # define xlim if not there already
-        rx + (diff(rx) * 0.01)              # add 1% to each side
+    rx <- range(as.numeric(time))       # max and min of dates
+    xlim <- x10 <- if(is.null(xlim)) {  # define xlim if not there already
+        rx + (diff(rx) * 0.01)          # add 1% to each side
     } else {
         as.numeric(xlim)
     }
@@ -31,17 +30,17 @@
                 cex.lab=1.3, bty="n", mar=c(4, 4, 1, 1) + 0.1)
         } else {
             par(lab=c(10, 10, 7), las=1, xaxs="i", cex.axis=0.7,
-                cex.lab=1.3, bty="n", mar=c(4, 4, 0, 1) + 0.1)
+                cex.lab=1.3, bty="n", mar=c(4, 4, -0.1, 1) + 0.1)
             layout(matrix(c(2, 1), nrow=2, ncol=1), heights=c(0.7, 1.5))
         }
         xZ <<- as.numeric(tclvalue(xZoom))
         xM <<- as.numeric(tclvalue(xlmid))
         xr.half <- (xr0/2) * 100/xZ
         xlim <- xM + c(-xr.half, xr.half)
-        xticks <- seq(from=xlim[1], to=xlim[2], length.out=20)
-        xticks <- chron(xticks)
-        xlabels <- gsub("[(]([0-9]+/[0-9]+)/[0-9]+ ([0-9]+:[0-9]+):[0-9]+.*",
-                        "\\1 \\2", as.character(xticks))
+        xticks <- chron(seq(from=xlim[1], to=xlim[2], length=20))
+        xlabels <- sprintf("%02i-%02i %02i:%02i:%02i",
+                           months(xticks), days(xticks),
+                           hours(xticks), minutes(xticks), seconds(xticks))
         yTop <<- as.numeric(tclvalue(yMax))
         ylim <- c(yTop, ylim[2])
         morn <- chron(dates=unique(dates(time)),
@@ -51,7 +50,7 @@
                        times=rep("18:00:00",
                            times=length(unique(dates(time)))))
         plot(depth ~ time, type="n", xlim=xlim, ylim=ylim,
-             xlab="date (dd/mm hh:mm)",
+             xlab="date (mm-dd hh:mm:ss)",
              ylab="depth (m)", xaxt="n", yaxt="n")
         usr <- par("usr")
         rect(night, usr[3], morn, usr[4], col="black")
@@ -69,7 +68,7 @@
                fill=c("white", "black"), cex=0.7, bg="white",
                y.intersp=1.2)
         if(!is.null(vel)) {
-            par(mar=c(0, 4, 1, 1) + 0.1)
+            par(mar=c(-0.1, 4, 1, 1) + 0.1)
             ylim <- range(vel, na.rm=TRUE)
             plot(vel ~ time, type="n", xaxt="n", ylim=ylim,
                  xlab="", xlim=xlim, bty="n", ylab="velocity (m/s)")
@@ -108,7 +107,7 @@
     tkpack(xmid.frame, xr.frame, dep.frame, side="left", anchor="s")
 
     but.frame <- tkframe(base)
-    zoc.pts <- tkbutton(but.frame, text="ZOC a range",
+    zoc.pts <- tkbutton(but.frame, text="Zero-Offset Correct a Range",
                         command=zocrange)
     q.but <- tkbutton(but.frame, text="      Quit       ",
                       command=function() tkdestroy(base))
@@ -117,7 +116,7 @@
     tkpack(base.frame, x.frame, but.frame)
 
     ## Zoom
-    tkpack(tklabel(xr.frame, text="Zoom in Date [%]"))
+    tkpack(tklabel(xr.frame, text="Date Zoom (%)"))
     tkpack(tkscale(xr.frame, command=replot.maybe, from=100,
                    to=30000, showvalue=TRUE, variable=xZoom,
                    length=200, orient="horiz"))
@@ -128,9 +127,9 @@
                    variable=xlmid, resolution=xr0/2000, length=200,
                    orient="horiz"))
     ## Maximum depth selection
-    tkpack(tklabel(dep.frame, text="Max. depth (m)"))
+    tkpack(tklabel(dep.frame, text="Max. Depth (m)"))
     tkpack(tkscale(dep.frame, command=replot.maybe,
-                   from=10, to=1000, length=150, showvalue=TRUE,
+                   from=0, to=1000, length=150, showvalue=TRUE,
                    variable=yMax, orient="horiz"))
 
     if(is.null(vel)) {x11(width=12)} else {x11(width=12, height=9)}
